<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kalzium" version="2">
<MenuBar>
  <Action name="change_pse" />
  <Action name="numerationtype" />
  <Menu name="miscmenu">
	<text>&amp;Miscellaneous</text>
	<Action name="use_timeline" />
	<Action name="plotdata" />
	<Action name="show_som" />
    <Action name="toggle_legend" />
  </Menu>
 <Action name="look_menu" />
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1" fullWidth="true" >
  <Action name="use_timeline" />
  <Action name="plotdata" />
  <Action name="show_som" />
  <Action name="toggle_legend" />
 </ToolBar>

</kpartgui>
