<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kmessedwords" version="2">
<MenuBar>
	<Menu name="file"><text>&amp;File</text>	
	  <Action name="play"/>
	  <Separator />
	  <Action name="show_highscores"/>
	  <Separator />
	</Menu>
	<Action name="level"/>
	<Menu name="settings"><text>&amp;Settings</text>
	  <Action name="dictionary" append="save_merge"/>
	</Menu>
</MenuBar>

</kpartgui>
